pub fn parse_comment_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<CommentNode, ParseError>Expand description
Parses a single line comment fragment for patch resolution using the selected language backend.
pub fn parse_comment_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<CommentNode, ParseError>Parses a single line comment fragment for patch resolution using the selected language backend.