pub fn parse_doc_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<DocNode, ParseError>Expand description
Parses a single doc comment fragment for patch resolution using the selected language backend.
pub fn parse_doc_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<DocNode, ParseError>Parses a single doc comment fragment for patch resolution using the selected language backend.