pub fn parse_field_fragment(source: &str) -> Result<Field, ParseError>Expand description
Parses a single struct field fragment for patch resolution.
pub fn parse_field_fragment(source: &str) -> Result<Field, ParseError>Parses a single struct field fragment for patch resolution.