pub fn parse_param_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<Param, ParseError>Expand description
Parses a single function parameter fragment for patch resolution using the selected language backend.
pub fn parse_param_fragment_for_language(
language: LowerLanguage,
source: &str,
) -> Result<Param, ParseError>Parses a single function parameter fragment for patch resolution using the selected language backend.